/*!
 * \file 
 * \brief Rs4852 Click example
 * 
 * # Description
 * This demo example shows RS485 communication using RS485 2 click.
 *
 * The demo application is composed of two sections :
 * 
 * ## Application Init 
 * Configuring clicks and log objects.
 * 
 * ## Application Task  
 * Depending on the selected application mode:
 *  - DEMO_APP_TRANSMITER - Prints "MikroE" message to UART
 *  - DEMO_APP_RECEIVER - Reads data from uart and prints to LOG (Default)
 * 
 * \author Katarina Perendic
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "board.h"
#include "log.h"
#include "rs4852.h"

// ------------------------------------------------------------------ VARIABLES

#define DEMO_APP_RECEIVER
//#define DEMO_APP_TRANSMITER

static rs4852_t rs4852;
static log_t logger;

static rs4852_data_t demo_message[ 9 ] = { 'M', 'i', 'k', 'r', 'o', 'E', 13, 10, 0 };

// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init ( void )
{
    log_cfg_t log_cfg;
    rs4852_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    rs4852_cfg_setup( &cfg );
    RS4852_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    rs4852_init( &rs4852, &cfg );
}

void application_task ( void )
{
    uint8_t tmp;

    //  Task implementation.

#ifdef DEMO_APP_RECEIVER

    // RECEIVER - UART polling

    tmp = rs4852_generic_single_read( &rs4852 );
    log_write( &logger, &tmp, LOG_FORMAT_BYTE );

#endif
#ifdef DEMO_APP_TRANSMITER

    // TRANSMITER - TX each 2 sec

    rs4852_generic_single_write( &rs4852, demo_message[ 0 ] );
    Delay_ms( 2000 );
#endif

}

void main ( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}


// ------------------------------------------------------------------------ END
