
 

---
# RS485 2 click

RS485 2 click is an RS422/485 transceiver Click board™, which can be used as an interface between the TTL level UART and the RS422/485 communication bus.

<p align="center">
  <img src="https://download.mikroe.com/images/click_for_ide/RS485-2.png">
</p>

[click Product page](<https://www.mikroe.com/rs485-2-click>)

---


#### Click library 

- **Author**        : Katarina Perendic
- **Date**          : okt 2019.
- **Type**          : UART type


# Software Support

We provide a library for the Rs4852 Click 
as well as a demo application (example), developed using MikroElektronika 
[compilers](http://shop.mikroe.com/compilers). 
The demo can run on all the main MikroElektronika [development boards](http://shop.mikroe.com/development-boards).

Package can be downloaded/installed directly form compilers IDE(recommended way), or downloaded from our LibStock, or found on mikroE github account. 

## Library Description

> This library contains API for Rs4852 Click driver.

#### Standard key functions :

- Config Object Initialization function.
> void rs4852_cfg_setup ( rs4852_cfg_t *cfg ); 
 
- Initialization function.
> RS4852_RETVAL rs4852_init ( rs4852_t *ctx, rs4852_cfg_t *cfg );

- Click Default Configuration function.
> void rs4852_default_cfg ( rs4852_t *ctx );


#### Example key functions :

- Power mode controle pins
> void rs4852_power_mode ( rs4852_t *ctx, uint8_t pin, uint8_t state );
 
- Generic single write function.
> void rs4852_generic_single_write ( rs4852_t *ctx, rs4852_data_t tx_data );

- Generic single read function.
> rs4852_data_t rs4852_generic_single_read ( rs4852_t *ctx );

## Examples Description

> This demo example shows RS485 communication using RS485 2 click.

**The demo application is composed of two sections :**

### Application Init 

> Configuring clicks and log objects.

```c
void application_init ( void )
{
    log_cfg_t log_cfg;
    rs4852_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    rs4852_cfg_setup( &cfg );
    RS4852_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    rs4852_init( &rs4852, &cfg );
}
```

### Application Task

> Depending on the selected application mode:
>  - DEMO_APP_TRANSMITER - Prints "MikroE" message to UART
>  - DEMO_APP_RECEIVER - Reads data from uart and prints to LOG (Default)

```c
void application_task ( void )
{
    uint8_t tmp;

    //  Task implementation.

#ifdef DEMO_APP_RECEIVER

    // RECEIVER - UART polling

    tmp = rs4852_generic_single_read( &rs4852 );
    log_write( &logger, &tmp, LOG_FORMAT_BYTE );

#endif
#ifdef DEMO_APP_TRANSMITER

    // TRANSMITER - TX each 2 sec

    rs4852_generic_single_write( &rs4852, demo_message[ 0 ] );
    Delay_ms( 2000 );
#endif

}
```

The full application code, and ready to use projects can be  installed directly form compilers IDE(recommneded) or found on LibStock page or mikroE GitHub accaunt.

**Other mikroE Libraries used in the example:** 

- MikroSDK.Board
- MikroSDK.Log
- Click.Rs4852

**Additional notes and informations**

Depending on the development board you are using, you may need 
[USB UART click](http://shop.mikroe.com/usb-uart-click), 
[USB UART 2 Click](http://shop.mikroe.com/usb-uart-2-click) or 
[RS232 Click](http://shop.mikroe.com/rs232-click) to connect to your PC, for 
development systems with no UART to USB interface available on the board. The 
terminal available in all Mikroelektronika 
[compilers](http://shop.mikroe.com/compilers), or any other terminal application 
of your choice, can be used to read the message.



---
